@@ -3,6 +3,7 @@ from django_comment_migrate.utils import get_field_comment
 
 
 class CommentMigration(BaseCommentMigration):
+    atomic = False
     sql_alter_column = "ALTER TABLE %(table)s %(changes)s"
     sql_alter_column_comment_null = "MODIFY COLUMN %(column)s %(type)s NULL" \
                                     " COMMENT %(comment)s"
@@ -12,6 +13,7 @@ class CommentMigration(BaseCommentMigration):
     def comments_sql(self):
         db_table = self.model._meta.db_table
         changes = []
+        params = []
         for field in self.model._meta.fields:
             comment = get_field_comment(field)
             if comment:
@@ -21,8 +23,9 @@ class CommentMigration(BaseCommentMigration):
                 changes.append(sql % {
                     "column": self.quote_name(field.column),
                     "type": db_parameters['type'],
-                    "comment": "'%s'" % comment
+                    "comment": "%s"
                 })
+                params.append(comment)
         if changes:
             return [
                 (
@@ -30,6 +33,6 @@ class CommentMigration(BaseCommentMigration):
                         "table": db_table,
                         "changes": ",".join(changes)
                     },
-                    []
+                    params
                 )
             ]
